@@ -13,9 +13,8 @@ class Config:
 @dataclass
 class Option:
     default: Any
-    type: Any = Any
     description: str = ''
-    parse: Callable = lambda x: x
+    type: Any = Any
 
 class ParseError(Exception):
     def __init__(self, *args, original_error: Exception()):
@@ -33,13 +32,13 @@ class Configurable:
         config_file: The Path object of the configuration file. 
     """
 
-    config: SuperDict = SuperDict()
+    config: SuperDict
     config_file: Path
 
     def __init__(self,
         manual_errors: bool = False
     ):
-
+        self.config = SuperDict()
         self.manual_errors = manual_errors
 
         if not hasattr(self, 'config_file'):
@@ -50,6 +49,35 @@ class Configurable:
 
         self.reload_config()
 
+    def reload_config(self):
+        """(Re)load the config option."""
+        _defaults = {}
+        for config in self._get_nested_configs():
+            _defaults.update(self.generate_defaults(config))
+        if hasattr(self, 'Config'):
+            _defaults.update(self.generate_defaults(self.Config))
+        if not _defaults:
+            return
+
+        if self.config_file.exists() and self.config_file.stat().st_size > 0:
+            with open(self.config_file, 'r') as file:
+                data = load(file)
+            self.load_config(data, _defaults, self.config)
+            self.config, updated = self.fill_config(_defaults, self.config)
+            if updated:
+                with open(self.config_file, 'w+') as file:
+                    document = self.document_from_config(_defaults, self.config)
+                    dump(document, file)
+        else:
+            self.config = self.generate_config(_defaults)
+            with open(self.config_file, 'w+') as file:
+                document = self.document_from_config(_defaults, self.config)
+                dump(document, file)
+
+        self.config = self.parse_config(_defaults, self.config)
+
+        del _defaults
+
     def _get_nested_configs(self):
         result = []
         for name in dir(self):
@@ -59,34 +87,6 @@ class Configurable:
                 result.append(obj)
         return result
 
-    def reload_config(self):
-        """(Re)load the config option."""
-        self._defaults = {}
-        for config in self._get_nested_configs():
-            self._defaults.update(self.generate_defaults(config))
-        if hasattr(self, 'Config'):
-            self._defaults.update(self.generate_defaults(self.Config))
-        if not self._defaults:
-            return
-
-        if self.config_file.exists() and self.config_file.stat().st_size > 0:
-            self.load_config()
-            self.config, updated = self.fill_config(self._defaults, self.config)
-            if updated: self.save_config()
-        else:
-            self.config = self.generate_config(self._defaults)
-            self.save_config()
-
-        if self.manual_errors:
-            self.config = self.parse_config(self._defaults, self.config)
-        else:
-            try:
-                self.config = self.parse_config(self._defaults, self.config)
-            except (ParseError, CheckError) as error:
-                print(error)
-
-        del self._defaults
-
     def generate_defaults(self, config: dict, defaults: dict = None):
         """Generate config defaults from classes."""
 
@@ -117,20 +117,20 @@ class Configurable:
         
         return defaults
 
-    def save_config(self):
-        """Save the config locally."""
-        with open(self.config_file, 'w+') as file:
-            dump(self.document_from_config(self._defaults, self.config), file)
-
-    def load_config(self):
+    def load_config(self, data, defaults, config):
         """Load a locally saved config."""
-        with open(self.config_file, 'r') as file:
-            data = load(file)
-            for key, value in data.items():
-                if not isinstance(value, bool):
-                    self.config[key] = value.value
-                else:
-                    self.config[key] = value
+        for key, value in data.items():
+            if key not in defaults:
+                continue
+            if isinstance(value, dict):
+                config[key] = SuperDict()
+                value = self.load_config(value, defaults[key], config[key])
+            if not isinstance(value, bool):
+                value = value.value
+            config[key] = value
+
+        return config
+
 
     def document_from_config(self, defaults: dict, config: dict) -> table():
         """Turn a config into a TOML Document with comments."""
@@ -141,7 +141,7 @@ class Configurable:
             if isinstance(value, dict):
                 document[key] = self.document_from_config(defaults[key], config[key])
             else:
-                document[key] = config[key]
+                document[key] = config[key]#.__repr__()
                 if value.description:
                     document.value.item(key).comment(value.description)
 
@@ -181,28 +181,48 @@ class Configurable:
     def parse_config(self, defaults: dict, config: dict) -> dict:
         """Parse config values and check types."""
         # go over every value in the config
+
         for key, value in config.items():
 
             # if the value isn't in the default values, ignore it
-            if key not in defaults: continue
+            if key not in defaults:
+                continue
+
+            default_data = defaults[key]
 
             # if dict, loop over it
             if isinstance(value, dict):
-                config[key] = self.parse_config(defaults[key], config[key])
+                value = self.parse_config(default_data, value)
                 continue
 
-            data = defaults[key]
+            try:
+                value = self.parse_value(key, value, default_data)
+            except (ParseError, CheckError) as error:
+                value = self.parse_value(key, default_data.default, default_data)
+                if self.manual_errors:
+                    raise error
+                print(error)
+    
+            config[key] = value
+            
+        return config
+
+    def parse_value(self, key, value, default_data):
+
+
+        if default_data.type != Any:
 
             try:
-                check_type(key, config[key], data.type)
-            except TypeError as check_error:
-                config[key] = data.default
-                raise CheckError(f"Error while trying to load option '{key}': '{str(check_error)}'", original_error=check_error) from check_error
+                value = default_data.type(value)
+            except ValueError as parse_error:
+                raise ParseError(f"Error while trying to parse option '{key}': {str(parse_error)}", original_error=parse_error) from parse_error
+            except TypeError:
+                pass
+            return value
 
-            try:
-                config[key] = data.parse(config[key])
-            except Exception as parse_error:
-                config[key] = data.default
-                raise ParseError(f"Error while trying to load option '{key}': '{str(parse_error)}'", original_error=parse_error) from parse_error
+        try:
+            check_type(key, value, default_data.type)
+        except TypeError as check_error:
+            raise CheckError(f"Error while trying to load option '{key}': {str(check_error)}", original_error=check_error) from check_error
 
-        return config
\ No newline at end of file
+        return value
\ No newline at end of file
